@@ -1,4 +1,4 @@
-// Copyright 2010-2020, Google Inc.
+// Copyright 2010-2021, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -35,9 +35,7 @@
 #else  // OS_WIN
 #ifdef __APPLE__
 #include <mach/mach_time.h>
-#elif defined(OS_NACL)  // __APPLE__
-#include <irt.h>
-#endif  // __APPLE__ or OS_NACL
+#endif  // __APPLE__
 #include <sys/time.h>
 #endif  // OS_WIN
 
@@ -49,7 +47,22 @@ namespace {
 
 class ClockImpl : public ClockInterface {
  public:
-  ClockImpl() : timezone_offset_sec_(0), timezone_(absl::LocalTimeZone()) {}
+  ClockImpl() : timezone_offset_sec_(0), timezone_(absl::LocalTimeZone()) {
+#if OS_WIN
+    // Because absl::LocalTimeZone() always returns UTC timezone on Windows,
+    // a work-around for Windows is required.
+    int offset_sec = 9 * 60 * 60;  // JST as fallback
+    const time_t epoch(24 * 60 * 60);  // 1970-01-02 00:00:00 UTC
+    const std::tm *offset = std::localtime(&epoch);
+    if (offset) {
+      offset_sec =
+          (offset->tm_mday - 2) * 24 * 60 * 60  // date offset from Jan 2.
+          + offset->tm_hour * 60 * 60  // hour offset from 00 am.
+          + offset->tm_min * 60;  // minute offset.
+    }
+    timezone_ = absl::FixedTimeZone(offset_sec);
+#endif  // OS_WIN
+  }
   ~ClockImpl() override {}
 
   void GetTimeOfDay(uint64 *sec, uint32 *usec) override {
@@ -103,8 +116,7 @@ class ClockImpl : public ClockInterface {
     mach_timebase_info(&timebase_info);
     return static_cast<uint64>(1.0e9 * timebase_info.denom /
                                timebase_info.numer);
-#elif defined(OS_LINUX) || defined(OS_ANDROID) || defined(OS_NACL) || \
-    defined(OS_WASM)
+#elif defined(OS_LINUX) || defined(OS_ANDROID) || defined(OS_WASM)
     return 1000000uLL;
 #else  // platforms (OS_WIN, __APPLE__, OS_LINUX, ...)
 #error "Not supported platform"
@@ -121,8 +133,7 @@ class ClockImpl : public ClockInterface {
     return static_cast<uint64>(timestamp.QuadPart);
 #elif defined(__APPLE__)
     return static_cast<uint64>(mach_absolute_time());
-#elif defined(OS_LINUX) || defined(OS_ANDROID) || defined(OS_NACL) || \
-    defined(OS_WASM)
+#elif defined(OS_LINUX) || defined(OS_ANDROID) || defined(OS_WASM)
     uint64 sec;
     uint32 usec;
     GetTimeOfDay(&sec, &usec);
