@@ -1,4 +1,4 @@
-// Copyright 2010-2020, Google Inc.
+// Copyright 2010-2021, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -34,8 +34,8 @@
 #include <iostream>
 #include <string>
 
-#include "base/flags.h"
 #include "base/port.h"
+#include "absl/flags/flag.h"
 
 namespace mozc {
 
@@ -292,7 +292,6 @@ class NullLogFinalizer {
 #define DVLOG(verboselevel) DLOG_IF(INFO, VLOG_IS_ON(verboselevel))
 
 
-
 #ifndef DVLOG_IF
 #define DVLOG_IF(verboselevel, condition) \
   DLOG_IF(INFO, (condition) && VLOG_IS_ON(verboselevel))
