@@ -1,4 +1,4 @@
-// Copyright 2010-2020, Google Inc.
+// Copyright 2010-2021, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -135,7 +135,7 @@ bool LoadPassword(std::string *password) {
     return false;
   }
 
-  // Seems that the size of DPAPI-encrypted-mesage
+  // Seems that the size of DPAPI-encrypted-message
   // becomes bigger than the original message.
   // Typical file size is 32 * 5 = 160byte.
   // We just set the maximum file size to be 4096byte just in case.
@@ -264,10 +264,9 @@ bool WinMacPasswordManager::RemovePassword() const {
 // We use plain text file for password storage on Linux. If you port this module
 // to other Linux distro, you might want to implement a new password manager
 // which adopts some secure mechanism such like gnome-keyring.
-#if defined(OS_LINUX) || defined(OS_ANDROID) || defined(OS_NACL) || \
-    defined(OS_WASM)
+#if defined(OS_LINUX) || defined(OS_ANDROID) || defined(OS_WASM)
 typedef PlainPasswordManager DefaultPasswordManager;
-#endif  // OS_LINUX || OS_ANDROID || OS_NACL
+#endif  // OS_LINUX || OS_ANDROID || OS_WASM
 
 // Windows or Mac
 #if (defined(OS_WIN) || defined(__APPLE__))
