@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2010-2018, Google Inc.
+# Copyright 2010-2021, Google Inc.
 # All rights reserved.
 #
 # Redistribution and use in source and binary forms, with or without
@@ -30,9 +30,13 @@
 
 """Generate a C++ array definition for file embedding."""
 
+from __future__ import absolute_import
+from __future__ import print_function
 import binascii
 import optparse
 import os
+import six
+from six.moves import range
 
 
 def _ParseOption():
@@ -46,33 +50,33 @@ def _ParseOption():
 
 def _FormatAsUint64LittleEndian(s):
   """Formats a string as uint64 value in little endian order."""
-  for _ in xrange(len(s), 8):
-    s += '\0'
+  for _ in range(len(s), 8):
+    s += six.b('\0')
   s = s[::-1]  # Reverse the string
-  return '0x%s' % binascii.b2a_hex(s)
+  return six.b('0x%s') % binascii.b2a_hex(s)
 
 
 def main():
   opts = _ParseOption()
   with open(opts.input, 'rb') as infile:
     with open(opts.output, 'wb') as outfile:
-      outfile.write(
+      outfile.write(six.b(
           '#ifdef MOZC_EMBEDDED_FILE_%(name)s\n'
           '#error "%(name)s was already included or defined elsewhere"\n'
           '#else\n'
           '#define MOZC_EMBEDDED_FILE_%(name)s\n'
           'const uint64 %(name)s_data[] = {\n'
-          % {'name': opts.name})
+          % {'name': opts.name}))
 
       while True:
         chunk = infile.read(8)
         if not chunk:
           break
-        outfile.write('  ')
+        outfile.write(six.b('  '))
         outfile.write(_FormatAsUint64LittleEndian(chunk))
-        outfile.write(',\n')
+        outfile.write(six.b(',\n'))
 
-      outfile.write(
+      outfile.write(six.b(
           '};\n'
           'const EmbeddedFile %(name)s = {\n'
           '  %(name)s_data,\n'
@@ -80,7 +84,7 @@ def main():
           '};\n'
           '#endif  // MOZC_EMBEDDED_FILE_%(name)s\n'
           % {'name': opts.name,
-             'size': os.stat(opts.input).st_size})
+             'size': os.stat(opts.input).st_size}))
 
 
 if __name__ == '__main__':
