@@ -1,4 +1,4 @@
-// Copyright 2010-2020, Google Inc.
+// Copyright 2010-2021, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -31,7 +31,6 @@
 
 #include "composer/composer.h"
 
-#include "base/flags.h"
 #include "base/logging.h"
 #include "base/util.h"
 #include "composer/internal/composition.h"
@@ -46,12 +45,13 @@
 #include "config/config_handler.h"
 #include "protocol/commands.pb.h"
 #include "protocol/config.pb.h"
+#include "absl/flags/flag.h"
 
 // Use flags instead of constant for performance evaluation.
-DEFINE_uint64(max_typing_correction_query_candidates, 40,
-              "Maximum # of typing correction query temporary candidates.");
-DEFINE_uint64(max_typing_correction_query_results, 8,
-              "Maximum # of typing correction query results.");
+ABSL_FLAG(uint64, max_typing_correction_query_candidates, 40,
+          "Maximum # of typing correction query temporary candidates.");
+ABSL_FLAG(uint64, max_typing_correction_query_results, 8,
+          "Maximum # of typing correction query results.");
 
 namespace mozc {
 namespace composer {
@@ -207,8 +207,9 @@ Composer::Composer(const Table *table, const commands::Request *request,
       input_field_type_(commands::Context::NORMAL),
       shifted_sequence_count_(0),
       composition_(new Composition(table)),
-      typing_corrector_(table, FLAGS_max_typing_correction_query_candidates,
-                        FLAGS_max_typing_correction_query_results),
+      typing_corrector_(
+          table, absl::GetFlag(FLAGS_max_typing_correction_query_candidates),
+          absl::GetFlag(FLAGS_max_typing_correction_query_results)),
       max_length_(kMaxPreeditLength),
       request_(request),
       config_(config) {
