@@ -1,4 +1,4 @@
-// Copyright 2010-2020, Google Inc.
+// Copyright 2010-2021, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -43,6 +43,7 @@
 #include "config/config_handler.h"
 #include "protocol/config.pb.h"
 #include "storage/lru_storage.h"
+#include "absl/memory/memory.h"
 
 namespace mozc {
 namespace config {
@@ -129,7 +130,7 @@ class PreeditCharacterFormManagerImpl : public CharacterFormManagerImpl {
  public:
   PreeditCharacterFormManagerImpl() { SetDefaultRule(); }
 
-  virtual void SetDefaultRule() {
+  void SetDefaultRule() override {
     Clear();
     // AddRule("ア", Config::FULL_WIDTH);
     AddRule("ア", Config::FULL_WIDTH);
@@ -157,7 +158,7 @@ class ConversionCharacterFormManagerImpl : public CharacterFormManagerImpl {
  public:
   ConversionCharacterFormManagerImpl() { SetDefaultRule(); }
 
-  virtual void SetDefaultRule() {
+  void SetDefaultRule() override {
     Clear();
     // AddRule("ア", Config::FULL_WIDTH);
     // don't like half-width
@@ -565,8 +566,8 @@ CharacterFormManager::Data::Data() {
   storage_.reset(LRUStorage::Create(filename.c_str(), sizeof(key_type),
                                     kLRUSize, kSeedValue));
   LOG_IF(ERROR, storage_.get() == nullptr) << "cannot open " << filename;
-  preedit_.reset(new PreeditCharacterFormManagerImpl);
-  conversion_.reset(new ConversionCharacterFormManagerImpl);
+  preedit_ = absl::make_unique<PreeditCharacterFormManagerImpl>();
+  conversion_ = absl::make_unique<ConversionCharacterFormManagerImpl>();
   preedit_->set_storage(storage_.get());
   conversion_->set_storage(storage_.get());
 }
