@@ -1,4 +1,4 @@
-// Copyright 2010-2020, Google Inc.
+// Copyright 2010-2021, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -131,7 +131,7 @@ bool ConfigHandlerImpl::GetStoredConfig(Config *config) const {
   return true;
 }
 
-// set config and rewirte internal data
+// set config and rewrite internal data
 bool ConfigHandlerImpl::SetConfigInternal(const Config &config) {
   stored_config_.CopyFrom(config);
 
@@ -322,11 +322,11 @@ void ConfigHandler::SetMetaData(Config *config) {
 Config::SessionKeymap ConfigHandler::GetDefaultKeyMap() {
 #if defined(__APPLE__)
   return config::Config::KOTOERI;
-#elif defined(OS_NACL)  // __APPLE__
+#elif defined(OS_CHROMEOS)  // __APPLE__
   return config::Config::CHROMEOS;
-#else                   // __APPLE__ or OS_NACL
+#else                   // __APPLE__ or OS_CHROMEOS
   return config::Config::MSIME;
-#endif                  // __APPLE__ or OS_NACL
+#endif                  // __APPLE__ or OS_CHROMEOS
 }
 
 }  // namespace config
