@@ -1,4 +1,4 @@
-// Copyright 2010-2020, Google Inc.
+// Copyright 2010-2021, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -52,10 +52,10 @@
 #include "base/mutex.h"
 #endif
 
-#if defined(OS_ANDROID) || defined(OS_NACL)
+#if defined(OS_ANDROID)
 #include "config/config_handler.h"
 #include "protocol/config.pb.h"
-#endif  // OS_ANDROID || OS_NACL
+#endif  // OS_ANDROID
 
 #include "base/file_util.h"
 #include "base/singleton.h"
@@ -249,9 +249,9 @@ class AndroidStatsConfigUtilImpl : public StatsConfigUtilInterface {
 class NullStatsConfigUtilImpl : public StatsConfigUtilInterface {
  public:
   NullStatsConfigUtilImpl() {}
-  virtual ~NullStatsConfigUtilImpl() {}
-  virtual bool IsEnabled() { return false; }
-  virtual bool SetEnabled(bool val) { return true; }
+  ~NullStatsConfigUtilImpl() override {}
+  bool IsEnabled() override { return false; }
+  bool SetEnabled(bool val) override { return true; }
 
  private:
   DISALLOW_COPY_AND_ASSIGN(NullStatsConfigUtilImpl);
@@ -270,8 +270,6 @@ typedef WinStatsConfigUtilImpl DefaultConfigUtilImpl;
 typedef MacStatsConfigUtilImpl DefaultConfigUtilImpl;
 #elif defined(OS_ANDROID)
 typedef AndroidStatsConfigUtilImpl DefaultConfigUtilImpl;
-#elif defined(OS_NACL)
-typedef NaclStatsConfigUtilImpl DefaultConfigUtilImpl;
 #else
 // Fall back mode.  Use null implementation.
 typedef NullStatsConfigUtilImpl DefaultConfigUtilImpl;
