@@ -1,4 +1,4 @@
-// Copyright 2010-2020, Google Inc.
+// Copyright 2010-2021, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -38,6 +38,7 @@
 #include "base/win_api_test_helper.h"
 #include "testing/base/public/googletest.h"
 #include "testing/base/public/gunit.h"
+#include "absl/flags/flag.h"
 
 #ifdef OS_ANDROID
 #include "config/config_handler.h"
@@ -670,8 +671,8 @@ TEST(StatsConfigUtilTestWin, IsEnabled) {
 
 #ifdef OS_ANDROID
 TEST(StatsConfigUtilTestAndroid, DefaultValueTest) {
-  const string config_file =
-      FileUtil::JoinPath(FLAGS_test_tmpdir, "mozc_stats_config_util_test_tmp");
+  const string config_file = FileUtil::JoinPath(
+      absl::GetFlag(FLAGS_test_tmpdir), "mozc_stats_config_util_test_tmp");
   FileUtil::Unlink(config_file);
   ConfigHandler::SetConfigFileName(config_file);
   EXPECT_EQ(config_file, ConfigHandler::GetConfigFileName());
@@ -684,11 +685,11 @@ TEST(StatsConfigUtilTestAndroid, DefaultValueTest) {
 }
 #endif  // OS_ANDROID
 
-#if defined(OS_LINUX) || defined(OS_NACL)
+#if defined(OS_LINUX)
 TEST(StatsConfigUtilTestLinux, DefaultValueTest) {
   EXPECT_FALSE(StatsConfigUtil::IsEnabled());
 }
-#endif  // OS_LINUX || OS_NACL
+#endif  // OS_LINUX
 
 #else  // !GOOGLE_JAPANESE_INPUT_BUILD
 TEST(StatsConfigUtilTestNonOfficialBuild, DefaultValueTest) {
