@@ -1,4 +1,4 @@
-// Copyright 2010-2020, Google Inc.
+// Copyright 2010-2021, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -44,6 +44,7 @@
 #include "dictionary/suppression_dictionary.h"
 #include "prediction/suggestion_filter.h"
 #include "testing/base/public/gunit.h"
+#include "absl/memory/memory.h"
 
 namespace mozc {
 namespace converter {
@@ -66,14 +67,14 @@ class CandidateFilterTest : public ::testing::Test {
   CandidateFilterTest() {}
 
   void SetUp() override {
-    candidate_freelist_.reset(new FreeList<Segment::Candidate>(1024));
-    node_freelist_.reset(new FreeList<Node>(1024));
+    candidate_freelist_ = absl::make_unique<FreeList<Segment::Candidate>>(1024);
+    node_freelist_ = absl::make_unique<FreeList<Node>>(1024);
     pos_matcher_.Set(mock_data_manager_.GetPOSMatcherData());
     {
       const char *data = nullptr;
       size_t size = 0;
       mock_data_manager_.GetSuggestionFilterData(&data, &size);
-      suggestion_filter_.reset(new SuggestionFilter(data, size));
+      suggestion_filter_ = absl::make_unique<SuggestionFilter>(data, size);
     }
   }
 
@@ -172,7 +173,7 @@ TEST_F(CandidateFilterTest, FilterTest) {
     filter->Reset();
   }
 
-  // Check if a canidate is active before appending many candidates.
+  // Check if a candidate is active before appending many candidates.
   Segment::Candidate *c4 = NewCandidate();
   for (size_t i = 0; i < arraysize(kRequestTypes); ++i) {
     EXPECT_EQ(CandidateFilter::GOOD_CANDIDATE,
