@@ -1,4 +1,4 @@
-// Copyright 2010-2020, Google Inc.
+// Copyright 2010-2021, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -41,7 +41,7 @@ namespace mozc {
 class ConverterMock : public ConverterInterface {
  public:
   ConverterMock();
-  virtual ~ConverterMock();
+  ~ConverterMock() override;
 
   // set next output of respective functions
   void SetStartConversionForRequest(Segments *segments, bool result);
