@@ -1,4 +1,4 @@
-// Copyright 2010-2020, Google Inc.
+// Copyright 2010-2021, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -59,6 +59,7 @@
 #include "protocol/commands.pb.h"
 #include "protocol/config.pb.h"
 #include "request/conversion_request.h"
+#include "absl/memory/memory.h"
 #include "absl/strings/string_view.h"
 
 using mozc::dictionary::DictionaryInterface;
@@ -331,14 +332,14 @@ void ImmutableConverterImpl::InsertDummyCandidates(Segment *segment,
           ? nullptr
           : segment->mutable_candidate(segment->candidates_size() - 1);
 
-  // Insert a dummy candiate whose content_value is katakana.
+  // Insert a dummy candidate whose content_value is katakana.
   // If functional_key() is empty, no need to make a dummy candidate.
   if (segment->candidates_size() > 0 &&
       segment->candidates_size() < expand_size &&
       !segment->candidate(0).functional_key().empty() &&
       Util::GetScriptType(segment->candidate(0).content_key) ==
           Util::HIRAGANA) {
-    // Use last_candidate as a refernce of cost.
+    // Use last_candidate as a reference of cost.
     // Use top_candidate as a refarence of lid/rid and key/value.
     DCHECK(top_candidate);
     DCHECK(last_candidate);
@@ -468,7 +469,7 @@ bool ImmutableConverterImpl::ResegmentArabicNumberAndSuffix(
         continue;
       }
 
-      // not compatibile
+      // not compatible
       if (number_value != number_key) {
         LOG(WARNING) << "Incompatible key/value number pair";
         continue;
@@ -544,7 +545,7 @@ bool ImmutableConverterImpl::ResegmentPrefixAndArabicNumber(
         continue;
       }
 
-      // not compatibile
+      // not compatible
       if (number_value != number_key) {
         LOG(WARNING) << "Incompatible key/value number pair";
         continue;
@@ -1638,7 +1639,8 @@ void ImmutableConverterImpl::MakeLatticeNodesForConversionSegments(
     if (request.config().preedit_method() != config::Config::ROMAN) {
       mode = KeyCorrector::KANA;
     }
-    key_corrector.reset(new KeyCorrector(key, mode, history_key.size()));
+    key_corrector =
+        absl::make_unique<KeyCorrector>(key, mode, history_key.size());
   }
 
   const bool is_reverse =
