@@ -1,4 +1,4 @@
-// Copyright 2010-2020, Google Inc.
+// Copyright 2010-2021, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -79,10 +79,17 @@ void SetCandidate(absl::string_view key, absl::string_view value,
   segment->set_key(key);
   Segment::Candidate *candidate = segment->add_candidate();
   candidate->Init();
+#ifdef ABSL_USES_STD_STRING_VIEW
+  candidate->key = key;
+  candidate->value = value;
+  candidate->content_key = key;
+  candidate->content_value = value;
+#else
   candidate->key = std::string(key);
   candidate->value = std::string(value);
   candidate->content_key = std::string(key);
   candidate->content_value = std::string(value);
+#endif  // ABSL_USES_STD_STRING_VIEW
 }
 
 const ConversionRequest &GetSimplifiedRankingConversionRequest() {
@@ -117,11 +124,11 @@ class MockDataAndImmutableConverter {
   explicit MockDataAndImmutableConverter(
       const DictionaryInterface *dictionary = nullptr,
       const DictionaryInterface *suffix_dictionary = nullptr) {
-    data_manager_.reset(new testing::MockDataManager);
+    data_manager_ = absl::make_unique<testing::MockDataManager>();
 
     pos_matcher_.Set(data_manager_->GetPOSMatcherData());
 
-    suppression_dictionary_.reset(new SuppressionDictionary);
+    suppression_dictionary_ = absl::make_unique<SuppressionDictionary>();
     CHECK(suppression_dictionary_.get());
 
     if (dictionary) {
@@ -148,8 +155,8 @@ class MockDataAndImmutableConverter {
       const uint32 *token_array;
       data_manager_->GetSuffixDictionaryData(
           &suffix_key_array_data, &suffix_value_array_data, &token_array);
-      suffix_dictionary_.reset(new SuffixDictionary(
-          suffix_key_array_data, suffix_value_array_data, token_array));
+      suffix_dictionary_ = absl::make_unique<SuffixDictionary>(
+          suffix_key_array_data, suffix_value_array_data, token_array);
       suffix_dictionary = suffix_dictionary_.get();
     }
     CHECK(suffix_dictionary);
@@ -159,20 +166,20 @@ class MockDataAndImmutableConverter {
     segmenter_.reset(Segmenter::CreateFromDataManager(*data_manager_));
     CHECK(segmenter_.get());
 
-    pos_group_.reset(new PosGroup(data_manager_->GetPosGroupData()));
+    pos_group_ = absl::make_unique<PosGroup>(data_manager_->GetPosGroupData());
     CHECK(pos_group_.get());
 
     {
       const char *data = nullptr;
       size_t size = 0;
       data_manager_->GetSuggestionFilterData(&data, &size);
-      suggestion_filter_.reset(new SuggestionFilter(data, size));
+      suggestion_filter_ = absl::make_unique<SuggestionFilter>(data, size);
     }
 
-    immutable_converter_.reset(new ImmutableConverterImpl(
+    immutable_converter_ = absl::make_unique<ImmutableConverterImpl>(
         dictionary_.get(), suffix_dictionary, suppression_dictionary_.get(),
         connector_.get(), segmenter_.get(), &pos_matcher_, pos_group_.get(),
-        suggestion_filter_.get()));
+        suggestion_filter_.get());
     CHECK(immutable_converter_.get());
   }
 
