@@ -1,4 +1,4 @@
-// Copyright 2010-2020, Google Inc.
+// Copyright 2010-2021, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -39,6 +39,7 @@
 #include "dictionary/dictionary_token.h"
 #include "request/conversion_request.h"
 #include "testing/base/public/gunit.h"
+#include "absl/memory/memory.h"
 
 namespace mozc {
 namespace dictionary {
@@ -46,7 +47,9 @@ namespace {
 
 class DictionaryMockTest : public ::testing::Test {
  protected:
-  void SetUp() override { mock_.reset(new DictionaryMock); }
+  void SetUp() override {
+    mock_ = absl::make_unique<DictionaryMock>();
+  }
 
   DictionaryMock *GetMock() { return mock_.get(); }
 
