@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2010-2020, Google Inc.
+# Copyright 2010-2021, Google Inc.
 # All rights reserved.
 #
 # Redistribution and use in source and binary forms, with or without
@@ -58,7 +58,6 @@ import optparse
 import re
 import sys
 import unicodedata
-import six
 
 from dictionary import zip_code_util
 
@@ -85,7 +84,7 @@ class ZipEntry(object):
     address = unicodedata.normalize('NFKC', self.address)
     line = '\t'.join([zip_code, '0', '0', str(ZIP_CODE_COST),
                       address, ZIP_CODE_LABEL])
-    print(six.ensure_str(line))
+    print(line)
 
 
 def ProcessZipCodeCSV(file_name):
