@@ -1,4 +1,4 @@
-// Copyright 2010-2020, Google Inc.
+// Copyright 2010-2021, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -291,7 +291,7 @@ class SystemDictionary::ReverseLookupIndex {
 
     CHECK_GE(value_id_max, 0);
     index_size_ = value_id_max + 1;
-    index_.reset(new ReverseLookupResultArray[index_size_]);
+    index_ = absl::make_unique<ReverseLookupResultArray[]>(index_size_);
 
     // Gets result size for each ids.
     for (TokenScanIterator iter(codec, token_array); !iter.Done();
@@ -304,7 +304,8 @@ class SystemDictionary::ReverseLookupIndex {
     }
 
     for (size_t i = 0; i < index_size_; ++i) {
-      index_[i].results.reset(new ReverseLookupResult[index_[i].size]);
+      index_[i].results =
+          absl::make_unique<ReverseLookupResult[]>(index_[i].size);
     }
 
     // Builds index.
@@ -533,7 +534,8 @@ void SystemDictionary::InitReverseLookupIndex() {
   if (reverse_lookup_index_ != nullptr) {
     return;
   }
-  reverse_lookup_index_.reset(new ReverseLookupIndex(codec_, token_array_));
+  reverse_lookup_index_ =
+      absl::make_unique<ReverseLookupIndex>(codec_, token_array_);
 }
 
 bool SystemDictionary::HasKey(absl::string_view key) const {
@@ -860,7 +862,7 @@ class ReverseLookupCallbackWrapper : public DictionaryInterface::Callback {
 
 }  // namespace
 
-// Recursive implemention of depth-first prefix search with key expansion.
+// Recursive implementation of depth-first prefix search with key expansion.
 // Input parameters:
 //   key:
 //     The head address of the original key before applying codec.
@@ -1047,7 +1049,7 @@ void SystemDictionary::PopulateReverseLookupCache(absl::string_view str) const {
     // as we have already built the index for reverse lookup.
     return;
   }
-  reverse_lookup_cache_.reset(new ReverseLookupCache);
+  reverse_lookup_cache_ = absl::make_unique<ReverseLookupCache>();
   DCHECK(reverse_lookup_cache_.get());
 
   // Iterate each suffix and collect IDs of all substrings.
