@@ -1,4 +1,4 @@
-// Copyright 2010-2020, Google Inc.
+// Copyright 2010-2021, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -412,11 +412,11 @@ UserDictionaryImporter::IMEType UserDictionaryImporter::GuessIMEType(
   }
 
   if (*line.begin() == '"' && *line.rbegin() == '"' &&
-      line.find("\t") == std::string::npos) {
+      line.find('\t') == std::string::npos) {
     return KOTOERI;
   }
 
-  if (*line.begin() == '#' || line.find("\t") != std::string::npos) {
+  if (*line.begin() == '#' || line.find('\t') != std::string::npos) {
     return MOZC;
   }
 
