@@ -1,4 +1,4 @@
-// Copyright 2010-2020, Google Inc.
+// Copyright 2010-2021, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -48,9 +48,9 @@ class TestInputIterator
  public:
   TestInputIterator() : index_(0), is_available_(false), entries_(nullptr) {}
 
-  bool IsAvailable() const { return is_available_; }
+  bool IsAvailable() const override { return is_available_; }
 
-  bool Next(UserDictionaryImporter::RawEntry *entry) {
+  bool Next(UserDictionaryImporter::RawEntry *entry) override {
     if (!is_available_) {
       return false;
     }
