@@ -1,4 +1,4 @@
-// Copyright 2010-2020, Google Inc.
+// Copyright 2010-2021, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -38,6 +38,7 @@
 #include "dictionary/user_dictionary_session.h"
 #include "dictionary/user_dictionary_util.h"
 #include "protocol/user_dictionary_storage.pb.h"
+#include "absl/memory/memory.h"
 
 namespace mozc {
 namespace user_dictionary {
@@ -153,7 +154,7 @@ void UserDictionarySessionHandler::CreateSession(
   uint64 new_id = CreateNewSessionId();
 
   session_id_ = new_id;
-  session_.reset(new UserDictionarySession(dictionary_path_));
+  session_ = absl::make_unique<UserDictionarySession>(dictionary_path_);
 
   status->set_status(
       UserDictionaryCommandStatus::USER_DICTIONARY_COMMAND_SUCCESS);
