@@ -1,4 +1,4 @@
-// Copyright 2010-2020, Google Inc.
+// Copyright 2010-2021, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -42,6 +42,7 @@
 #include "dictionary/user_dictionary_util.h"
 #include "testing/base/public/googletest.h"
 #include "testing/base/public/gunit.h"
+#include "absl/flags/flag.h"
 
 namespace mozc {
 namespace {
@@ -63,19 +64,19 @@ std::string GenRandomString(int size) {
 
 class UserDictionaryStorageTest : public ::testing::Test {
  protected:
-  virtual void SetUp() {
+  void SetUp() override {
     backup_user_profile_directory_ = SystemUtil::GetUserProfileDirectory();
-    SystemUtil::SetUserProfileDirectory(FLAGS_test_tmpdir);
+    SystemUtil::SetUserProfileDirectory(absl::GetFlag(FLAGS_test_tmpdir));
     FileUtil::Unlink(GetUserDictionaryFile());
   }
 
-  virtual void TearDown() {
+  void TearDown() override {
     FileUtil::Unlink(GetUserDictionaryFile());
     SystemUtil::SetUserProfileDirectory(backup_user_profile_directory_);
   }
 
   static std::string GetUserDictionaryFile() {
-    return FileUtil::JoinPath(FLAGS_test_tmpdir, "test.db");
+    return FileUtil::JoinPath(absl::GetFlag(FLAGS_test_tmpdir), "test.db");
   }
 
  private:
@@ -216,7 +217,7 @@ TEST_F(UserDictionaryStorageTest, ExportTest) {
   }
 
   const std::string export_file =
-      FileUtil::JoinPath(FLAGS_test_tmpdir, "export.txt");
+      FileUtil::JoinPath(absl::GetFlag(FLAGS_test_tmpdir), "export.txt");
 
   EXPECT_FALSE(storage.ExportDictionary(id + 1, export_file));
   EXPECT_TRUE(storage.ExportDictionary(id, export_file));
@@ -431,7 +432,7 @@ TEST_F(UserDictionaryStorageTest, ConvertSyncDictionariesToNormalDictionaries) {
 TEST_F(UserDictionaryStorageTest, Export) {
   const int kDummyDictionaryId = 10;
   const std::string kPath =
-      FileUtil::JoinPath(FLAGS_test_tmpdir, "exported_file");
+      FileUtil::JoinPath(absl::GetFlag(FLAGS_test_tmpdir), "exported_file");
 
   {
     UserDictionaryStorage storage(GetUserDictionaryFile());
