@@ -1,4 +1,4 @@
-// Copyright 2010-2020, Google Inc.
+// Copyright 2010-2021, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -38,6 +38,7 @@
 #include "data_manager/testing/mock_data_manager.h"
 #include "dictionary/user_pos_interface.h"
 #include "testing/base/public/gunit.h"
+#include "absl/memory/memory.h"
 #include "absl/strings/string_view.h"
 
 namespace mozc {
@@ -49,7 +50,7 @@ class UserPOSTest : public ::testing::Test {
   void SetUp() override {
     absl::string_view token_array_data, string_array_data;
     mock_data_manager_.GetUserPOSData(&token_array_data, &string_array_data);
-    user_pos_.reset(new UserPOS(token_array_data, string_array_data));
+    user_pos_ = absl::make_unique<UserPOS>(token_array_data, string_array_data);
     CHECK(user_pos_.get());
   }
 
