@@ -1,4 +1,4 @@
-// Copyright 2010-2020, Google Inc.
+// Copyright 2010-2021, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -153,7 +153,7 @@ void CharacterFormEditor::Load(const config::Config &config) {
     // Preedit Katakan is always FULLWIDTH
     // This item should not be editable
     if (group == QObject::tr("Katakana")) {
-      item_preedit->setFlags(nullptr);  // disable flag
+      item_preedit->setFlags(Qt::NoItemFlags);  // disable flag
     }
 
     setItem(row, 0, item_group);
