@@ -1,4 +1,4 @@
-// Copyright 2010-2018, Google Inc.
+// Copyright 2010-2021, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -32,29 +32,30 @@
 #include <string>
 #include <vector>
 
-#include "base/flags.h"
 #include "base/init_mozc.h"
 #include "base/logging.h"
 #include "base/port.h"
 #include "base/thread.h"
 #include "ipc/ipc.h"
+#include "absl/flags/flag.h"
 
-DEFINE_string(server_address, "ipc_test", "");
-DEFINE_bool(test, false, "automatic test mode");
-DEFINE_bool(server, false, "invoke as server mode");
-DEFINE_bool(client, false, "invoke as client mode");
-DEFINE_string(server_path, "", "server path");
-DEFINE_int32(num_threads, 10, "number of threads");
-DEFINE_int32(num_requests, 100, "number of requests");
+ABSL_FLAG(std::string, server_address, "ipc_test", "");
+ABSL_FLAG(bool, test, false, "automatic test mode");
+ABSL_FLAG(bool, server, false, "invoke as server mode");
+ABSL_FLAG(bool, client, false, "invoke as client mode");
+ABSL_FLAG(std::string, server_path, "", "server path");
+ABSL_FLAG(int32, num_threads, 10, "number of threads");
+ABSL_FLAG(int32, num_requests, 100, "number of requests");
 
 namespace mozc {
 
-class MultiConnections: public Thread {
+class MultiConnections : public Thread {
  public:
   void Run() {
     char buf[8192];
-    for (int i = 0; i < FLAGS_num_requests; ++i) {
-      mozc::IPCClient con(FLAGS_server_address, FLAGS_server_path);
+    for (int i = 0; i < absl::GetFlag(FLAGS_num_requests); ++i) {
+      mozc::IPCClient con(FLAGS_server_address,
+                          absl::GetFlag(FLAGS_server_path));
       CHECK(con.Connected());
       string input = "testtesttesttest";
       size_t length = sizeof(buf);
@@ -67,28 +68,23 @@ class MultiConnections: public Thread {
   }
 };
 
-class EchoServer: public IPCServer {
+class EchoServer : public IPCServer {
  public:
-  EchoServer(const string &path,
-             int32 num_connections,
-             int32 timeout) :
-      IPCServer(path, num_connections, timeout) {}
-  virtual bool Process(const char *input_buffer,
-                       size_t input_length,
-                       char *output_buffer,
-                       size_t *output_length) {
+  EchoServer(const string &path, int32 num_connections, int32 timeout)
+      : IPCServer(path, num_connections, timeout) {}
+  virtual bool Process(const char *input_buffer, size_t input_length,
+                       char *output_buffer, size_t *output_length) {
     ::memcpy(output_buffer, input_buffer, input_length);
     *output_length = input_length;
     return ::memcmp("kill", input_buffer, 4) != 0;
   }
 };
 
-class EchoServerThread: public Thread {
+class EchoServerThread : public Thread {
  public:
-  explicit EchoServerThread(EchoServer *con): con_(con) {}
-  virtual void Run() {
-    con_->Loop();
-  }
+  explicit EchoServerThread(EchoServer *con) : con_(con) {}
+  virtual void Run() { con_->Loop(); }
+
  private:
   EchoServer *con_;
 };
@@ -96,15 +92,15 @@ class EchoServerThread: public Thread {
 }  // namespace mozc
 
 int main(int argc, char **argv) {
-  mozc::InitMozc(argv[0], &argc, &argv, false);
+  mozc::InitMozc(argv[0], &argc, &argv);
 
-  if (FLAGS_test) {
-    mozc::EchoServer con(FLAGS_server_address, 10, 1000);
+  if (absl::GetFlag(FLAGS_test)) {
+    mozc::EchoServer con(absl::GetFlag(FLAGS_server_address), 10, 1000);
     mozc::EchoServerThread server_thread_main(&con);
     server_thread_main.SetJoinable(true);
     server_thread_main.Start("IpcMain");
 
-    std::vector<mozc::MultiConnections> cons(FLAGS_num_threads);
+    std::vector<mozc::MultiConnections> cons(absl::GetFlag(FLAGS_num_threads));
     for (size_t i = 0; i < cons.size(); ++i) {
       cons[i].SetJoinable(true);
       cons[i].Start("MultiConnections");
@@ -113,33 +109,32 @@ int main(int argc, char **argv) {
       cons[i].Join();
     }
 
-    mozc::IPCClient kill(FLAGS_server_address, FLAGS_server_path);
+    mozc::IPCClient kill(FLAGS_server_address,
+                         absl::GetFlag(FLAGS_server_path));
     const char kill_cmd[32] = "kill";
     char output[32];
     size_t output_size = sizeof(output);
-    kill.Call(kill_cmd, strlen(kill_cmd),
-              output, &output_size, 1000);
-              server_thread_main.Join();
+    kill.Call(kill_cmd, strlen(kill_cmd), output, &output_size, 1000);
+    server_thread_main.Join();
 
     LOG(INFO) << "Done";
 
-  } else if (FLAGS_server) {
-    mozc::EchoServer con(FLAGS_server_address,
-                         10, -1);
+  } else if (absl::GetFlag(FLAGS_server)) {
+    mozc::EchoServer con(absl::GetFlag(FLAGS_server_address), 10, -1);
     CHECK(con.Connected());
-    LOG(INFO) << "Start Server at " << FLAGS_server_address;
+    LOG(INFO) << "Start Server at " << absl::GetFlag(FLAGS_server_address);
     con.Loop();
-  } else if (FLAGS_client) {
+  } else if (absl::GetFlag(FLAGS_client)) {
     string line;
     char response[8192];
     while (getline(cin, line)) {
-      mozc::IPCClient con(FLAGS_server_address, FLAGS_server_path);
+      mozc::IPCClient con(FLAGS_server_address,
+                          absl::GetFlag(FLAGS_server_path));
       CHECK(con.Connected());
       size_t response_size = sizeof(response);
-      CHECK(con.Call(line.data(), line.size(),
-                     response, &response_size, 1000));
-      cout << "Request: " << line << endl;
-      cout << "Response: " << string(response, response_size) << endl;
+      CHECK(con.Call(line.data(), line.size(), response, &response_size, 1000));
+      std::cout << "Request: " << line << std::endl;
+      std::cout << "Response: " << string(response, response_size) << std::endl;
     }
   } else {
     LOG(INFO) << "either --server or --client or --test must be set true";
