@@ -1,4 +1,4 @@
-// Copyright 2010-2020, Google Inc.
+// Copyright 2010-2021, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -32,7 +32,6 @@
 #include <algorithm>
 #include <vector>
 
-#include "base/flags.h"
 #include "base/port.h"
 #include "base/system_util.h"
 #include "base/thread.h"
@@ -40,6 +39,7 @@
 #include "ipc/ipc_test_util.h"
 #include "testing/base/public/googletest.h"
 #include "testing/base/public/gunit.h"
+#include "absl/flags/flag.h"
 
 namespace {
 
@@ -73,7 +73,7 @@ class MultiConnections : public mozc::Thread {
   }
 #endif
 
-  void Run() {
+  void Run() override {
     char buf[8192];
     mozc::Util::Sleep(2000);
     for (int i = 0; i < kNumRequests; ++i) {
@@ -103,8 +103,8 @@ class EchoServer : public mozc::IPCServer {
  public:
   EchoServer(const std::string &path, int32 num_connections, int32 timeout)
       : IPCServer(path, num_connections, timeout) {}
-  virtual bool Process(const char *input_buffer, size_t input_length,
-                       char *output_buffer, size_t *output_length) {
+  bool Process(const char *input_buffer, size_t input_length,
+               char *output_buffer, size_t *output_length) override {
     if (::memcmp("kill", input_buffer, 4) == 0) {
       *output_length = 0;
       return false;
@@ -117,7 +117,7 @@ class EchoServer : public mozc::IPCServer {
 }  // namespace
 
 TEST(IPCTest, IPCTest) {
-  mozc::SystemUtil::SetUserProfileDirectory(FLAGS_test_tmpdir);
+  mozc::SystemUtil::SetUserProfileDirectory(absl::GetFlag(FLAGS_test_tmpdir));
 #ifdef __APPLE__
   mozc::TestMachPortManager manager;
 #endif
