@@ -1,4 +1,4 @@
-// Copyright 2010-2020, Google Inc.
+// Copyright 2010-2021, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -99,10 +99,10 @@ class ProcessWatchDog : public Thread {
   bool SetID(ProcessID process_id, ThreadID thread_id, int timeout);
 
   // internally used by thread
-  void Run();
+  void Run() override;
 
   ProcessWatchDog();
-  virtual ~ProcessWatchDog();
+  ~ProcessWatchDog() override;
   void StartWatchDog();
   void StopWatchDog();
 
