@@ -1,4 +1,4 @@
-// Copyright 2010-2020, Google Inc.
+// Copyright 2010-2021, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -32,8 +32,8 @@
 #import "DialogsController.h"
 #import "Uninstaller.h"
 
-#include "base/flags.h"
 #include "base/init_mozc.h"
+#include "absl/flags/flag.h"
 
 int main(int argc, char *argv[]) {
   mozc::InitMozc(argv[0], &argc, &argv);
