@@ -1,4 +1,4 @@
-// Copyright 2010-2020, Google Inc.
+// Copyright 2010-2021, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -42,9 +42,9 @@ class DataManagerInterface;
 class CollocationRewriter : public RewriterInterface {
  public:
   explicit CollocationRewriter(const DataManagerInterface *data_manager);
-  virtual ~CollocationRewriter();
-  virtual bool Rewrite(const ConversionRequest &request,
-                       Segments *segments) const;
+  ~CollocationRewriter() override;
+  bool Rewrite(const ConversionRequest &request,
+               Segments *segments) const override;
 
  private:
   class CollocationFilter;
