@@ -1,4 +1,4 @@
-// Copyright 2010-2020, Google Inc.
+// Copyright 2010-2021, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -49,6 +49,7 @@
 #include "testing/base/public/mozctest.h"
 #include "usage_stats/usage_stats.h"
 #include "usage_stats/usage_stats_testing_util.h"
+#include "absl/memory/memory.h"
 #include "absl/strings/string_view.h"
 
 namespace mozc {
@@ -59,7 +60,8 @@ using mozc::commands::Request;
 const char kEmoji[] = "えもじ";
 
 // Makes |segments| to have only a segment with a key-value paired candidate.
-void SetSegment(const string &key, const string &value, Segments *segments) {
+void SetSegment(const std::string &key, const std::string &value,
+                Segments *segments) {
   segments->Clear();
   Segment *seg = segments->push_back_segment();
   seg->set_key(key);
@@ -86,7 +88,7 @@ int CountEmojiCandidates(const Segments &segments) {
 
 // Checks if the first segment has a specific candidate.
 bool HasExpectedCandidate(const Segments &segments,
-                          const string &expect_value) {
+                          const std::string &expect_value) {
   CHECK_LE(1, segments.segments_size());
   const Segment &segment = segments.segment(0);
   for (size_t i = 0; i < segment.candidates_size(); ++i) {
@@ -157,7 +159,7 @@ class TestDataManager : public testing::MockDataManager {
  public:
   TestDataManager() {
     // Collect all the strings and temporarily assign 0 as index.
-    std::map<string, size_t> string_index;
+    std::map<std::string, size_t> string_index;
     for (const EmojiData &data : kTestEmojiList) {
       string_index[data.key] = 0;
       string_index[data.unicode] = 0;
@@ -220,8 +222,8 @@ class EmojiRewriterTest : public ::testing::Test {
 
     mozc::usage_stats::UsageStats::ClearAllStatsForTest();
 
-    rewriter_.reset(new EmojiRewriter(test_data_manager_));
-    full_data_rewriter_.reset(new EmojiRewriter(mock_data_manager_));
+    rewriter_ = absl::make_unique<EmojiRewriter>(test_data_manager_);
+    full_data_rewriter_ = absl::make_unique<EmojiRewriter>(mock_data_manager_);
   }
 
   void TearDown() override {
@@ -410,14 +412,14 @@ TEST_F(EmojiRewriterTest, CheckDescription) {
   const Segment &segment = segments.segment(0);
   for (int i = 0; i < segment.candidates_size(); ++i) {
     const Segment::Candidate &candidate = segment.candidate(i);
-    const string &description = candidate.description;
+    const std::string &description = candidate.description;
     // Skip non emoji candidates.
     if (!EmojiRewriter::IsEmojiCandidate(candidate)) {
       continue;
     }
-    EXPECT_NE(string::npos, description.find("<機種依存文字>"))
+    EXPECT_NE(std::string::npos, description.find("<機種依存文字>"))
         << "for \"" << candidate.value << "\" : \"" << description << "\"";
-    EXPECT_EQ(string::npos, description.find("[全]"))
+    EXPECT_EQ(std::string::npos, description.find("[全]"))
         << "for \"" << candidate.value << "\" : \"" << description << "\"";
   }
 }
@@ -435,7 +437,7 @@ TEST_F(EmojiRewriterTest, CheckInsertPosition) {
     Segment *segment = segments.push_back_segment();
     segment->set_key("Neko");
     for (int i = 0; i < kExpectPosition * 2; ++i) {
-      string value = "candidate" + std::to_string(i);
+      std::string value = "candidate" + std::to_string(i);
       Segment::Candidate *candidate = segment->add_candidate();
       candidate->Init();
       candidate->value = value;
