@@ -1,4 +1,4 @@
-// Copyright 2010-2020, Google Inc.
+// Copyright 2010-2021, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -45,6 +45,7 @@
 #include "protocol/config.pb.h"
 #include "request/conversion_request.h"
 #include "rewriter/rewriter_interface.h"
+#include "absl/memory/memory.h"
 #include "absl/strings/string_view.h"
 
 namespace mozc {
@@ -74,7 +75,7 @@ void InsertCandidates(SerializedDictionary::const_iterator begin,
                       size_t initial_insert_pos, size_t initial_insert_size,
                       bool is_no_learning, Segment *segment) {
   if (segment->candidates_size() == 0) {
-    LOG(WARNING) << "candiadtes_size is 0";
+    LOG(WARNING) << "candidates_size is 0";
     return;
   }
 
@@ -89,7 +90,7 @@ void InsertCandidates(SerializedDictionary::const_iterator begin,
 
   std::sort(sorted_value.begin(), sorted_value.end(), ValueCostCompare());
 
-  // after sorting the valeus by |cost|, adjacent candidates
+  // after sorting the values by |cost|, adjacent candidates
   // will have the same value. It is almost OK to use std::unique to
   // remove dup entries, it is not a perfect way though.
   sorted_value.erase(
@@ -219,8 +220,8 @@ std::unique_ptr<EmoticonRewriter> EmoticonRewriter::CreateFromDataManager(
     const DataManagerInterface &data_manager) {
   absl::string_view token_array_data, string_array_data;
   data_manager.GetEmoticonRewriterData(&token_array_data, &string_array_data);
-  return std::unique_ptr<EmoticonRewriter>(
-      new EmoticonRewriter(token_array_data, string_array_data));
+  return absl::make_unique<EmoticonRewriter>(token_array_data,
+                                             string_array_data);
 }
 
 EmoticonRewriter::EmoticonRewriter(absl::string_view token_array_data,
