@@ -1,4 +1,4 @@
-// Copyright 2010-2020, Google Inc.
+// Copyright 2010-2021, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -54,7 +54,7 @@ bool EnglishVariantsRewriter::ExpandEnglishVariants(
   }
 
   // multi-word
-  if (input.find(" ") != std::string::npos) {
+  if (input.find(' ') != std::string::npos) {
     return false;
   }
 
@@ -120,7 +120,7 @@ bool EnglishVariantsRewriter::ExpandEnglishVariantsWithSegment(
     DCHECK(original_candidate);
 
     // http://b/issue?id=5137299
-    // If the entry is comming from user dictionary,
+    // If the entry is coming from user dictionary,
     // expand English variants.
     if (original_candidate->attributes &
             Segment::Candidate::NO_VARIANTS_EXPANSION &&
