@@ -1,4 +1,4 @@
-// Copyright 2010-2020, Google Inc.
+// Copyright 2010-2021, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -41,6 +41,8 @@
 #include "testing/base/public/googletest.h"
 #include "testing/base/public/gunit.h"
 #include "transliteration/transliteration.h"
+#include "absl/flags/flag.h"
+#include "absl/memory/memory.h"
 
 namespace mozc {
 namespace {
@@ -64,9 +66,9 @@ void AddCandidateWithContentValue(Segment *segment, const std::string &value,
 
 class FocusCandidateRewriterTest : public ::testing::Test {
  protected:
-  virtual void SetUp() {
-    SystemUtil::SetUserProfileDirectory(FLAGS_test_tmpdir);
-    rewriter_.reset(new FocusCandidateRewriter(&mock_data_manager_));
+  void SetUp() override {
+    SystemUtil::SetUserProfileDirectory(absl::GetFlag(FLAGS_test_tmpdir));
+    rewriter_ = absl::make_unique<FocusCandidateRewriter>(&mock_data_manager_);
   }
 
   const RewriterInterface *GetRewriter() { return rewriter_.get(); }
