@@ -1,4 +1,4 @@
-// Copyright 2010-2020, Google Inc.
+// Copyright 2010-2021, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -45,6 +45,7 @@
 #include "protocol/config.pb.h"
 #include "request/conversion_request.h"
 #include "rewriter/rewriter_interface.h"
+#include "absl/memory/memory.h"
 #include "absl/strings/string_view.h"
 
 using mozc::dictionary::POSMatcher;
@@ -379,8 +380,8 @@ SingleKanjiRewriter::SingleKanjiRewriter(
 
   DCHECK(SerializedDictionary::VerifyData(noun_prefix_token_array_data,
                                           noun_prefix_string_array_data));
-  noun_prefix_dictionary_.reset(new SerializedDictionary(
-      noun_prefix_token_array_data, noun_prefix_string_array_data));
+  noun_prefix_dictionary_ = absl::make_unique<SerializedDictionary>(
+      noun_prefix_token_array_data, noun_prefix_string_array_data);
 }
 
 SingleKanjiRewriter::~SingleKanjiRewriter() {}
