@@ -1,4 +1,4 @@
-// Copyright 2010-2020, Google Inc.
+// Copyright 2010-2021, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -46,6 +46,7 @@
 #include "protocol/config.pb.h"
 #include "request/conversion_request.h"
 #include "rewriter/rewriter_interface.h"
+#include "absl/memory/memory.h"
 #include "absl/strings/string_view.h"
 
 // SymbolRewriter:
@@ -169,7 +170,7 @@ void SymbolRewriter::InsertCandidates(
     size_t default_offset, const SerializedDictionary::IterRange &range,
     bool context_sensitive, Segment *segment) {
   if (segment->candidates_size() == 0) {
-    LOG(WARNING) << "candiadtes_size is 0";
+    LOG(WARNING) << "candidates_size is 0";
     return;
   }
 
@@ -180,7 +181,7 @@ void SymbolRewriter::InsertCandidates(
   // register space to CharacterFormManager.
   ExpandSpace(segment);
 
-  // If the original candidates given by ImmutableConveter already
+  // If the original candidates given by ImmutableConverter already
   // include the target symbols, do assign description to these candidates.
   AddDescForCurrentCandidates(range, segment);
 
@@ -345,8 +346,8 @@ SymbolRewriter::SymbolRewriter(const ConverterInterface *parent_converter,
   absl::string_view token_array_data, string_array_data;
   data_manager->GetSymbolRewriterData(&token_array_data, &string_array_data);
   DCHECK(SerializedDictionary::VerifyData(token_array_data, string_array_data));
-  dictionary_.reset(
-      new SerializedDictionary(token_array_data, string_array_data));
+  dictionary_ = absl::make_unique<SerializedDictionary>(token_array_data,
+                                                        string_array_data);
 }
 
 SymbolRewriter::~SymbolRewriter() {}
