@@ -1,4 +1,4 @@
-// Copyright 2010-2020, Google Inc.
+// Copyright 2010-2021, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -142,10 +142,10 @@ class ScoreTypeCompare {
   }
 };
 
-// return the first candiadte which has "BEST_CANDIDATE" attribute
+// return the first candidate which has "BEST_CANDIDATE" attribute
 inline int GetDefaultCandidateIndex(const Segment &segment) {
   // Check up to kMaxRerankSize + 1 candidates because candidate with
-  // BEST_CANDIATE is highly possibly in that range (http://b/9992330).
+  // BEST_CANDIDATE is highly possibly in that range (http://b/9992330).
   const int size =
       static_cast<int>(std::min(segment.candidates_size(), kMaxRerankSize + 1));
   for (int i = 0; i < size; ++i) {
@@ -690,7 +690,7 @@ void UserSegmentHistoryRewriter::RememberFirstCandidate(
   const std::string &all_key = seg.key();
   const std::string &content_key = candidate.content_key;
 
-  // even if the candiate was the top (default) candidate,
+  // even if the candidate was the top (default) candidate,
   // ERANKED will be set when user changes the ranking
   const bool force_insert =
       ((candidate.attributes & Segment::Candidate::RERANKED) != 0);
@@ -759,7 +759,7 @@ bool UserSegmentHistoryRewriter::IsAvailable(const ConversionRequest &request,
     return false;
   }
 
-  if (storage_.get() == nullptr) {
+  if (storage_ == nullptr) {
     VLOG(2) << "storage is NULL";
     return false;
   }
@@ -1017,7 +1017,7 @@ bool UserSegmentHistoryRewriter::Rewrite(const ConversionRequest &request,
 }
 
 void UserSegmentHistoryRewriter::Clear() {
-  if (storage_.get() != nullptr) {
+  if (storage_ != nullptr) {
     VLOG(1) << "Clearing user segment data";
     storage_->Clear();
   }
