@@ -1,4 +1,4 @@
-// Copyright 2010-2020, Google Inc.
+// Copyright 2010-2021, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -27,7 +27,6 @@
 // (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 // OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
-#include "absl/flags/flag.h"
 #ifdef OS_WIN
 #include <windows.h>
 #include <ws2tcpip.h>
@@ -47,7 +46,6 @@ using ssize_t = SSIZE_T;
 #include <string>
 #include <vector>
 
-#include "base/flags.h"
 #include "base/init_mozc.h"
 #include "base/singleton.h"
 #include "base/system_util.h"
@@ -56,14 +54,15 @@ using ssize_t = SSIZE_T;
 #include "session/random_keyevents_generator.h"
 #include "session/session_handler.h"
 #include "session/session_usage_observer.h"
+#include "absl/flags/flag.h"
 
-DEFINE_string(host, "localhost", "server host name");
-DEFINE_bool(server, true, "server mode");
-DEFINE_bool(client, false, "client mode");
-DEFINE_int32(client_test_size, 100, "client test size");
-DEFINE_int32(port, 8000, "port of RPC server");
-DEFINE_int32(rpc_timeout, 60000, "timeout");
-DEFINE_string(user_profile_directory, "", "user profile directory");
+ABSL_FLAG(std::string, host, "localhost", "server host name");
+ABSL_FLAG(bool, server, true, "server mode");
+ABSL_FLAG(bool, client, false, "client mode");
+ABSL_FLAG(int32, client_test_size, 100, "client test size");
+ABSL_FLAG(int32, port, 8000, "port of RPC server");
+ABSL_FLAG(int32, rpc_timeout, 60000, "timeout");
+ABSL_FLAG(std::string, user_profile_directory, "", "user profile directory");
 
 namespace mozc {
 
@@ -144,7 +143,7 @@ class RPCServer {
 #endif
 
     ::memset(&sin, 0, sizeof(sin));
-    sin.sin_port = htons(mozc::GetFlag(FLAGS_port));
+    sin.sin_port = htons(absl::GetFlag(FLAGS_port));
     sin.sin_family = AF_INET;
     sin.sin_addr.s_addr = htonl(INADDR_ANY);
 
@@ -182,7 +181,7 @@ class RPCServer {
       uint32 request_size = 0;
       // Receive the size of data.
       if (!Recv(client_socket, reinterpret_cast<char *>(&request_size),
-                sizeof(request_size), mozc::GetFlag(FLAGS_rpc_timeout))) {
+                sizeof(request_size), absl::GetFlag(FLAGS_rpc_timeout))) {
         LOG(ERROR) << "Cannot receive request_size header.";
         CloseSocket(client_socket);
         continue;
@@ -194,7 +193,7 @@ class RPCServer {
       // Receive the body of serialized protobuf.
       std::unique_ptr<char[]> request_str(new char[request_size]);
       if (!Recv(client_socket, request_str.get(), request_size,
-                mozc::GetFlag(FLAGS_rpc_timeout))) {
+                absl::GetFlag(FLAGS_rpc_timeout))) {
         LOG(ERROR) << "cannot receive body of request.";
         CloseSocket(client_socket);
         continue;
@@ -220,9 +219,9 @@ class RPCServer {
       output_size = htonl(output_size);
 
       if (!Send(client_socket, reinterpret_cast<char *>(&output_size),
-                sizeof(output_size), mozc::GetFlag(FLAGS_rpc_timeout)) ||
+                sizeof(output_size), absl::GetFlag(FLAGS_rpc_timeout)) ||
           !Send(client_socket, output_str.data(), output_str.size(),
-                mozc::GetFlag(FLAGS_rpc_timeout))) {
+                absl::GetFlag(FLAGS_rpc_timeout))) {
         LOG(ERROR) << "Cannot send reply.";
       }
 
@@ -284,8 +283,8 @@ class RPCClient {
     hints.ai_socktype = SOCK_STREAM;
     hints.ai_family = AF_INET;
 
-    const std::string port_str = std::to_string(mozc::GetFlag(FLAGS_port));
-    CHECK_EQ(::getaddrinfo(mozc::GetFlag(FLAGS_host).c_str(), port_str.c_str(),
+    const std::string port_str = std::to_string(absl::GetFlag(FLAGS_port));
+    CHECK_EQ(::getaddrinfo(absl::GetFlag(FLAGS_host).c_str(), port_str.c_str(),
                            &hints, &res),
              0)
         << "getaddrinfo failed";
@@ -304,20 +303,20 @@ class RPCClient {
     request_size = htonl(request_size);
 
     CHECK(Send(client_socket, reinterpret_cast<char *>(&request_size),
-               sizeof(request_size), mozc::GetFlag(FLAGS_rpc_timeout)));
+               sizeof(request_size), absl::GetFlag(FLAGS_rpc_timeout)));
     CHECK(Send(client_socket, request_str.data(), request_str.size(),
-               mozc::GetFlag(FLAGS_rpc_timeout)));
+               absl::GetFlag(FLAGS_rpc_timeout)));
 
     uint32 output_size = 0;
     CHECK(Recv(client_socket, reinterpret_cast<char *>(&output_size),
-               sizeof(output_size), mozc::GetFlag(FLAGS_rpc_timeout)));
+               sizeof(output_size), absl::GetFlag(FLAGS_rpc_timeout)));
     output_size = ntohl(output_size);
     CHECK_GT(output_size, 0);
     CHECK_LT(output_size, kMaxOutputSize);
 
     std::unique_ptr<char[]> output_str(new char[output_size]);
     CHECK(Recv(client_socket, output_str.get(), output_size,
-               mozc::GetFlag(FLAGS_rpc_timeout)));
+               absl::GetFlag(FLAGS_rpc_timeout)));
 
     CHECK(output->ParseFromArray(output_str.get(), output_size));
 
@@ -355,16 +354,17 @@ int main(int argc, char *argv[]) {
 
   mozc::ScopedWSAData wsadata;
 
-  if (!mozc::GetFlag(FLAGS_user_profile_directory).empty()) {
+  if (!absl::GetFlag(FLAGS_user_profile_directory).empty()) {
     LOG(INFO) << "Setting user profile directory to "
-              << FLAGS_user_profile_directory;
-    mozc::SystemUtil::SetUserProfileDirectory(FLAGS_user_profile_directory);
+              << absl::GetFlag(FLAGS_user_profile_directory);
+    mozc::SystemUtil::SetUserProfileDirectory(
+        absl::GetFlag(FLAGS_user_profile_directory));
   }
 
-  if (mozc::GetFlag(FLAGS_client)) {
+  if (absl::GetFlag(FLAGS_client)) {
     mozc::RPCClient client;
     CHECK(client.CreateSession());
-    for (int n = 0; n < mozc::GetFlag(FLAGS_client_test_size); ++n) {
+    for (int n = 0; n < absl::GetFlag(FLAGS_client_test_size); ++n) {
       std::vector<mozc::commands::KeyEvent> keys;
       mozc::session::RandomKeyEventsGenerator::GenerateSequence(&keys);
       for (size_t i = 0; i < keys.size(); ++i) {
@@ -376,7 +376,7 @@ int main(int argc, char *argv[]) {
     }
     CHECK(client.DeleteSession());
     return 0;
-  } else if (mozc::GetFlag(FLAGS_server)) {
+  } else if (absl::GetFlag(FLAGS_server)) {
     mozc::RPCServer server;
     server.Loop();
   } else {
