@@ -1,4 +1,4 @@
-// Copyright 2010-2020, Google Inc.
+// Copyright 2010-2021, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -33,16 +33,17 @@
 #include <string>
 
 #include "testing/base/public/gunit.h"
+#include "absl/memory/memory.h"
 
 namespace mozc {
 namespace session {
 
 class CandidateListTest : public testing::Test {
  protected:
-  virtual void SetUp() {
-    main_list_.reset(new CandidateList(true));
-    sub_list_2_.reset(new CandidateList(true));
-    sub_sub_list_2_1_.reset(new CandidateList(false));
+  void SetUp() override {
+    main_list_ = absl::make_unique<CandidateList>(true);
+    sub_list_2_ = absl::make_unique<CandidateList>(true);
+    sub_sub_list_2_1_ = absl::make_unique<CandidateList>(false);
 
     main_list_->AddCandidate(0, "0");                           // main0
     main_list_->AddCandidate(1, "1");                           // main1
