@@ -1,4 +1,4 @@
-// Copyright 2010-2020, Google Inc.
+// Copyright 2010-2021, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -59,6 +59,7 @@
 #include "session/session_converter.h"
 #include "session/session_usage_stats_util.h"
 #include "usage_stats/usage_stats.h"
+#include "absl/memory/memory.h"
 
 namespace mozc {
 namespace session {
@@ -229,21 +230,21 @@ void Session::InitContext(ImeContext *context) const {
   context->SetConfig(&context->GetConfig());
 
 #if defined(OS_ANDROID) || defined(OS_IOS) || defined(OS_LINUX) || \
-    defined(OS_NACL)
+    defined(OS_WASM)
   context->mutable_converter()->set_use_cascading_window(false);
-#endif  // OS_ANDROID || OS_IOS || OS_LINUX || OS_NACL
+#endif  // OS_ANDROID || OS_IOS || OS_LINUX || OS_WASM
 }
 
 void Session::PushUndoContext() {
   // TODO(komatsu): Support multiple undo.
-  prev_context_.reset(new ImeContext);
+  prev_context_ = absl::make_unique<ImeContext>();
   InitContext(prev_context_.get());
   ImeContext::CopyContext(*context_, prev_context_.get());
 }
 
 void Session::PopUndoContext() {
   // TODO(komatsu): Support multiple undo.
-  if (!prev_context_.get()) {
+  if (!prev_context_) {
     return;
   }
   context_.swap(prev_context_);
@@ -466,8 +467,7 @@ bool Session::TestSendKey(commands::Command *command) {
 
     // If undo context is empty, echoes back the key event so that it can be
     // handled by the application. b/5553298
-    if (key_command == keymap::PrecompositionState::UNDO &&
-        !prev_context_.get()) {
+    if (key_command == keymap::PrecompositionState::UNDO && !prev_context_) {
       return EchoBack(command);
     }
 
@@ -964,14 +964,14 @@ void Session::UpdatePreferences(commands::Command *command) {
   }
 
 #if defined(OS_ANDROID) || defined(OS_IOS) || defined(OS_LINUX) || \
-    defined(OS_NACL)
+    defined(OS_WASM)
   context_->mutable_converter()->set_use_cascading_window(false);
-#else   // OS_LINUX || OS_ANDROID || OS_NACL
+#else   // OS_LINUX || OS_ANDROID || OS_WASM
   if (config.has_use_cascading_window()) {
     context_->mutable_converter()->set_use_cascading_window(
         config.use_cascading_window());
   }
-#endif  // OS_ANDROID || OS_IOS || OS_LINUX || OS_NACL
+#endif  // OS_ANDROID || OS_IOS || OS_LINUX || OS_WASM
 }
 
 bool Session::IMEOn(commands::Command *command) {
@@ -1198,7 +1198,7 @@ bool Session::RequestUndo(commands::Command *command) {
 
   // If undo context is empty, echoes back the key event so that it can be
   // handled by the application. b/5553298
-  if (context_->state() == ImeContext::PRECOMPOSITION && !prev_context_.get()) {
+  if (context_->state() == ImeContext::PRECOMPOSITION && !prev_context_) {
     return EchoBack(command);
   }
 
@@ -1221,7 +1221,7 @@ bool Session::Undo(commands::Command *command) {
   command->mutable_output()->set_consumed(true);
 
   // Check the undo context
-  if (!prev_context_.get()) {
+  if (!prev_context_) {
     return DoNothing(command);
   }
 
@@ -1443,7 +1443,7 @@ bool Session::InsertCharacter(commands::Command *command) {
   bool should_commit = (context_->state() == ImeContext::CONVERSION);
 
   if (context_->GetRequest().space_on_alphanumeric() ==
-          commands::Request::SPACE_OR_CONVERT_COMMITING_COMPOSITION &&
+          commands::Request::SPACE_OR_CONVERT_COMMITTING_COMPOSITION &&
       context_->state() == ImeContext::COMPOSITION &&
       // TODO(komatsu): Support FullWidthSpace
       Util::EndsWith(composition, " ")) {
@@ -2204,7 +2204,7 @@ bool Session::UndoOrRewind(commands::Command *command) {
   }
 
   // Undo if we can order UNDO command.
-  if (prev_context_.get()) {
+  if (prev_context_) {
     return Undo(command);
   }
 
@@ -2289,7 +2289,7 @@ bool Session::Convert(commands::Command *command) {
         return Commit(command);
       } else {
         // SPACE_OR_CONVERT_KEEPING_COMPOSITION or
-        // SPACE_OR_CONVERT_COMMITING_COMPOSITION.
+        // SPACE_OR_CONVERT_COMMITTING_COMPOSITION.
 
         // If the last character is not space, space is inserted to the
         // composition.
