@@ -1,4 +1,4 @@
-// Copyright 2010-2020, Google Inc.
+// Copyright 2010-2021, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -44,15 +44,16 @@
 #include "session/session_converter.h"
 #include "testing/base/public/googletest.h"
 #include "testing/base/public/gunit.h"
+#include "absl/flags/flag.h"
 
-DEFINE_bool(test_deterministic, true,
-            "if true, srand() is initialized by \"test_srand_seed\"."
-            "if false, srand() is initialized by current time "
-            "and \"test_srand_seed\" is ignored");
+ABSL_FLAG(bool, test_deterministic, true,
+          "if true, srand() is initialized by \"test_srand_seed\"."
+          "if false, srand() is initialized by current time "
+          "and \"test_srand_seed\" is ignored");
 
-DEFINE_int32(test_srand_seed, 0,
-             "seed number for srand(). "
-             "used only when \"test_deterministic\" is true");
+ABSL_FLAG(int32, test_srand_seed, 0,
+          "seed number for srand(). "
+          "used only when \"test_deterministic\" is true");
 
 namespace mozc {
 
@@ -63,14 +64,16 @@ namespace session {
 class SessionConverterStressTest : public ::testing::Test {
  public:
   SessionConverterStressTest() {
-    if (!FLAGS_test_deterministic) {
-      FLAGS_test_srand_seed = static_cast<int32>(Clock::GetTime());
+    if (!absl::GetFlag(FLAGS_test_deterministic)) {
+      absl::SetFlag(&FLAGS_test_srand_seed,
+                    static_cast<int32>(Clock::GetTime()));
     }
-    Util::SetRandomSeed(static_cast<uint32>(FLAGS_test_srand_seed));
+    Util::SetRandomSeed(
+        static_cast<uint32>(absl::GetFlag(FLAGS_test_srand_seed)));
   }
 
-  virtual void SetUp() {
-    SystemUtil::SetUserProfileDirectory(FLAGS_test_tmpdir);
+  void SetUp() override {
+    SystemUtil::SetUserProfileDirectory(absl::GetFlag(FLAGS_test_tmpdir));
     config::Config config;
     config::ConfigHandler::GetDefaultConfig(&config);
     config::ConfigHandler::SetConfig(config);
