@@ -1,4 +1,4 @@
-// Copyright 2010-2020, Google Inc.
+// Copyright 2010-2021, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -39,16 +39,12 @@
 #include "engine/engine_interface.h"
 #include "protocol/commands.pb.h"
 #include "protocol/config.pb.h"
+#include "session/session_handler_interface.h"
 #include "testing/base/public/gunit.h"
 #include "usage_stats/usage_stats_testing_util.h"
 
 namespace mozc {
-
-class SessionHandlerInterface;
-
 namespace session {
-class SessionObserverInterface;
-
 namespace testing {
 
 // Sends CREATE_SESSION command to the given handler and returns its result.
@@ -63,10 +59,6 @@ bool DeleteSession(SessionHandlerInterface *handler, uint64 id);
 // Sends CLEANUP command to the given handler, and returns its result.
 bool CleanUp(SessionHandlerInterface *handler, uint64 id);
 
-// Sends CLEAR_USER_PREDICTION command to the given handler and returns its
-// result.
-bool CleanUserPrediction(SessionHandlerInterface *handler, uint64 id);
-
 // Returns the session represented by the given id is "good" or not, based
 // on sending a SPACE key. See the implementation for the detail.
 bool IsGoodSession(SessionHandlerInterface *handler, uint64 id);
@@ -98,53 +90,6 @@ class SessionHandlerTestBase : public ::testing::Test {
   DISALLOW_COPY_AND_ASSIGN(SessionHandlerTestBase);
 };
 
-// Session utility for stress tests.
-class TestSessionClient {
- public:
-  explicit TestSessionClient(std::unique_ptr<EngineInterface> engine);
-  ~TestSessionClient();
-
-  bool CreateSession();
-  bool DeleteSession();
-  bool CleanUp();
-  bool ClearUserPrediction();
-  bool SendKey(const commands::KeyEvent &key, commands::Output *output) {
-    return SendKeyWithOption(key, commands::Input::default_instance(), output);
-  }
-  bool SendKeyWithOption(const commands::KeyEvent &key,
-                         const commands::Input &option,
-                         commands::Output *output);
-  bool TestSendKey(const commands::KeyEvent &key, commands::Output *output) {
-    return TestSendKeyWithOption(key, commands::Input::default_instance(),
-                                 output);
-  }
-  bool TestSendKeyWithOption(const commands::KeyEvent &key,
-                             const commands::Input &option,
-                             commands::Output *output);
-  bool SelectCandidate(uint32 id, commands::Output *output);
-  bool SubmitCandidate(uint32 id, commands::Output *output);
-
-  bool Reload();
-  bool ResetContext();
-  bool UndoOrRewind(commands::Output *output);
-  bool SwitchInputMode(commands::CompositionMode composition_mode);
-  bool SetRequest(const commands::Request &request, commands::Output *output);
-  bool SetConfig(const config::Config &config, commands::Output *output);
-  void SetCallbackText(const std::string &text);
-
- private:
-  bool EvalCommand(commands::Input *input, commands::Output *output);
-  bool EvalCommandInternal(commands::Input *input, commands::Output *output,
-                           bool allow_callback);
-
-  uint64 id_;
-  std::unique_ptr<SessionObserverInterface> usage_observer_;
-  std::unique_ptr<SessionHandlerInterface> handler_;
-  std::string callback_text_;
-
-  DISALLOW_COPY_AND_ASSIGN(TestSessionClient);
-};
-
 }  // namespace testing
 }  // namespace session
 }  // namespace mozc
