@@ -1,4 +1,4 @@
-// Copyright 2010-2020, Google Inc.
+// Copyright 2010-2021, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -47,6 +47,8 @@
 #include "usage_stats/usage_stats.h"
 #include "usage_stats/usage_stats.pb.h"
 #include "usage_stats/usage_stats_testing_util.h"
+#include "absl/flags/flag.h"
+#include "absl/memory/memory.h"
 
 using mozc::usage_stats::Stats;
 using mozc::usage_stats::UsageStats;
@@ -56,20 +58,20 @@ namespace session {
 
 class SessionUsageObserverTest : public testing::Test {
  protected:
-  virtual void SetUp() {
-    SystemUtil::SetUserProfileDirectory(FLAGS_test_tmpdir);
+  void SetUp() override {
+    SystemUtil::SetUserProfileDirectory(absl::GetFlag(FLAGS_test_tmpdir));
     UsageStats::ClearAllStatsForTest();
 
     Clock::SetClockForUnitTest(nullptr);
 
-    scheduler_stub_.reset(new SchedulerStub);
+    scheduler_stub_ = absl::make_unique<SchedulerStub>();
     Scheduler::SetSchedulerHandler(scheduler_stub_.get());
 
-    stats_config_util_mock_.reset(new config::StatsConfigUtilMock);
+    stats_config_util_mock_ = absl::make_unique<config::StatsConfigUtilMock>();
     config::StatsConfigUtil::SetHandler(stats_config_util_mock_.get());
   }
 
-  virtual void TearDown() {
+  void TearDown() override {
     Clock::SetClockForUnitTest(nullptr);
     Scheduler::SetSchedulerHandler(nullptr);
     config::StatsConfigUtil::SetHandler(nullptr);
