@@ -1,4 +1,4 @@
-// Copyright 2010-2020, Google Inc.
+// Copyright 2010-2021, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -44,6 +44,7 @@
 #include "storage/lru_cache.h"
 #include "testing/base/public/googletest.h"
 #include "testing/base/public/gunit.h"
+#include "absl/flags/flag.h"
 
 namespace mozc {
 namespace storage {
@@ -136,7 +137,8 @@ class LRUStorageTest : public ::testing::Test {
 
   static std::string GetTemporaryFilePath() {
     // This name should be unique to each test.
-    return FileUtil::JoinPath(FLAGS_test_tmpdir, "LRUStorageTest_test.db");
+    return FileUtil::JoinPath(absl::GetFlag(FLAGS_test_tmpdir),
+                              "LRUStorageTest_test.db");
   }
 
  private:
@@ -243,7 +245,7 @@ TEST_F(LRUStorageTest, Merge) {
 
   {
     // Need to mock clock because old entries are removed on Open.  The maximum
-    // timestmap set below is 50, so set the current time to 100.
+    // timestamp set below is 50, so set the current time to 100.
     ScopedClockMock clock(100, 0);
 
     LRUStorage::CreateStorageFile(file1.c_str(), 4, 8, kSeed);
@@ -286,7 +288,7 @@ TEST_F(LRUStorageTest, Merge) {
   // same FP
   {
     // Need to mock clock because old entries are removed on Open.  The maximum
-    // timestmap set below is 50, so set the current time to 100.
+    // timestamp set below is 50, so set the current time to 100.
     ScopedClockMock clock(100, 0);
 
     LRUStorage::CreateStorageFile(file1.c_str(), 4, 8, kSeed);
