@@ -1,4 +1,4 @@
-// Copyright 2010-2016, Google Inc.
+// Copyright 2010-2021, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -36,6 +36,7 @@
 #include "config/stats_config_util.h"
 #include "storage/registry.h"
 #include "usage_stats/usage_stats.pb.h"
+#include "usage_stats/usage_stats_uploader.h"
 
 namespace mozc {
 namespace usage_stats {
@@ -45,34 +46,10 @@ const char kRegistryPrefix[] = "usage_stats.";
 
 #include "usage_stats/usage_stats_list.h"
 
-void AddDoubleValueStats(
-    const Stats::DoubleValueStats &src,
-    Stats::DoubleValueStats *dest) {
-  dest->set_num(src.num() + dest->num());
-  dest->set_total(src.total() + dest->total());
-  dest->set_square_total(src.square_total() + dest->square_total());
-}
-
-void AddTouchEventStats(
-    const Stats::TouchEventStats &src_stats,
-    Stats::TouchEventStats *dest_stats) {
-  dest_stats->set_source_id(src_stats.source_id());
-  AddDoubleValueStats(src_stats.start_x_stats(),
-                      dest_stats->mutable_start_x_stats());
-  AddDoubleValueStats(src_stats.start_y_stats(),
-                      dest_stats->mutable_start_y_stats());
-  AddDoubleValueStats(src_stats.direction_x_stats(),
-                      dest_stats->mutable_direction_x_stats());
-  AddDoubleValueStats(src_stats.direction_y_stats(),
-                      dest_stats->mutable_direction_y_stats());
-  AddDoubleValueStats(src_stats.time_length_stats(),
-                      dest_stats->mutable_time_length_stats());
-}
-
-bool LoadStats(const string &name, Stats *stats) {
+bool LoadStats(const std::string &name, Stats *stats) {
   DCHECK(UsageStats::IsListed(name)) << name << " is not in the list";
-  string stats_str;
-  const string key = kRegistryPrefix + name;
+  std::string stats_str;
+  const std::string key = kRegistryPrefix + name;
   if (!mozc::storage::Registry::Lookup(key, &stats_str)) {
     VLOG(1) << "Usage stats " << name << " is not registered yet.";
     return false;
@@ -84,30 +61,21 @@ bool LoadStats(const string &name, Stats *stats) {
   return true;
 }
 
-bool GetterInternal(const string &name, Stats::Type type, Stats *stats) {
+bool GetterInternal(const std::string &name, Stats::Type type, Stats *stats) {
   if (!LoadStats(name, stats)) {
     return false;
   }
   if (stats->type() != type) {
-    LOG(ERROR) << "Type of " << name << " is not " << type
-               << " but " << stats->type() << ".";
+    LOG(ERROR) << "Type of " << name << " is not " << type << " but "
+               << stats->type() << ".";
     return false;
   }
   return true;
 }
 
-bool SetterInternal(const string &name, const Stats &stats) {
-  const string key = kRegistryPrefix + name;
-  const string stats_str = stats.SerializeAsString();
-  if (!storage::Registry::Insert(key, stats_str)) {
-    LOG(ERROR) << "cannot save " << name << " to registry";
-    return false;
-  }
-  return true;
-}
 }  // namespace
 
-bool UsageStats::IsListed(const string &name) {
+bool UsageStats::IsListed(const std::string &name) {
   for (size_t i = 0; i < arraysize(kStatsList); ++i) {
     if (name == kStatsList[i]) {
       return true;
@@ -117,16 +85,15 @@ bool UsageStats::IsListed(const string &name) {
 }
 
 void UsageStats::ClearStats() {
-  string stats_str;
+  std::string stats_str;
   Stats stats;
   for (size_t i = 0; i < arraysize(kStatsList); ++i) {
-    const string key = string(kRegistryPrefix) + kStatsList[i];
+    const std::string key = std::string(kRegistryPrefix) + kStatsList[i];
     if (storage::Registry::Lookup(key, &stats_str)) {
       if (!stats.ParseFromString(stats_str)) {
         storage::Registry::Erase(key);
       }
-      if (stats.type() == Stats::INTEGER ||
-          stats.type() == Stats::BOOLEAN) {
+      if (stats.type() == Stats::INTEGER || stats.type() == Stats::BOOLEAN) {
         // We do not clear integer/boolean stats.
         // These stats do not accumulate.
         // We want send these stats at the next time
@@ -138,86 +105,34 @@ void UsageStats::ClearStats() {
   }
 }
 
-void UsageStats::ClearAllStatsForTest() {
+void UsageStats::ClearAllStats() {
   for (size_t i = 0; i < arraysize(kStatsList); ++i) {
-    const string key = string(kRegistryPrefix) + kStatsList[i];
+    const std::string key = std::string(kRegistryPrefix) + kStatsList[i];
     storage::Registry::Erase(key);
   }
 }
 
-void UsageStats::IncrementCountBy(const string &name, uint32 val) {
+void UsageStats::IncrementCountBy(const std::string &name, uint32 val) {
   DCHECK(IsListed(name)) << name << " is not in the list";
-  if (!config::StatsConfigUtil::IsEnabled()) {
-    return;
-  }
-
-  Stats stats;
-  if (GetterInternal(name, Stats::COUNT, &stats)) {
-    stats.set_count(stats.count() + val);
-  } else {
-    stats.set_name(name);
-    stats.set_type(Stats::COUNT);
-    stats.set_count(val);
-  }
-
-  SetterInternal(name, stats);
+  // Does nothing
 }
 
-void UsageStats::UpdateTiming(const string &name, uint32 val) {
+void UsageStats::UpdateTiming(const std::string &name, uint32 val) {
   DCHECK(IsListed(name)) << name << " is not in the list";
-  if (!config::StatsConfigUtil::IsEnabled()) {
-    return;
-  }
-
-  Stats stats;
-  if (GetterInternal(name, Stats::TIMING, &stats)) {
-    stats.set_num_timings(stats.num_timings() + 1);
-    stats.set_total_time(stats.total_time() + val);
-    stats.set_avg_time(stats.total_time() / stats.num_timings());
-    stats.set_min_time(min(stats.min_time(), val));
-    stats.set_max_time(max(stats.max_time(), val));
-  } else {
-    stats.set_name(name);
-    stats.set_type(Stats::TIMING);
-    stats.set_num_timings(1);
-    stats.set_total_time(val);
-    stats.set_avg_time(val);
-    stats.set_min_time(val);
-    stats.set_max_time(val);
-  }
-
-  SetterInternal(name, stats);
+  // Does nothing
 }
 
-void UsageStats::SetInteger(const string &name, int val) {
+void UsageStats::SetInteger(const std::string &name, int val) {
   DCHECK(IsListed(name)) << name << " is not in the list";
-  if (!config::StatsConfigUtil::IsEnabled()) {
-    return;
-  }
-
-  Stats stats;
-  stats.set_name(name);
-  stats.set_type(Stats::INTEGER);
-  stats.set_int_value(val);
-
-  SetterInternal(name, stats);
+  // Does nothing
 }
 
-void UsageStats::SetBoolean(const string &name, bool val) {
+void UsageStats::SetBoolean(const std::string &name, bool val) {
   DCHECK(IsListed(name)) << name << " is not in the list";
-  if (!config::StatsConfigUtil::IsEnabled()) {
-    return;
-  }
-
-  Stats stats;
-  stats.set_name(name);
-  stats.set_type(Stats::BOOLEAN);
-  stats.set_boolean_value(val);
-
-  SetterInternal(name, stats);
+  // Does nothing
 }
 
-bool UsageStats::GetCountForTest(const string &name, uint32 *value) {
+bool UsageStats::GetCountForTest(const std::string &name, uint32 *value) {
   CHECK(value != NULL);
   Stats stats;
   if (!GetterInternal(name, Stats::COUNT, &stats)) {
@@ -232,7 +147,7 @@ bool UsageStats::GetCountForTest(const string &name, uint32 *value) {
   return true;
 }
 
-bool UsageStats::GetIntegerForTest(const string &name, int32 *value) {
+bool UsageStats::GetIntegerForTest(const std::string &name, int32 *value) {
   CHECK(value != NULL);
   Stats stats;
   if (!GetterInternal(name, Stats::INTEGER, &stats)) {
@@ -247,7 +162,7 @@ bool UsageStats::GetIntegerForTest(const string &name, int32 *value) {
   return true;
 }
 
-bool UsageStats::GetBooleanForTest(const string &name, bool *value) {
+bool UsageStats::GetBooleanForTest(const std::string &name, bool *value) {
   CHECK(value != NULL);
   Stats stats;
   if (!GetterInternal(name, Stats::BOOLEAN, &stats)) {
@@ -262,12 +177,9 @@ bool UsageStats::GetBooleanForTest(const string &name, bool *value) {
   return true;
 }
 
-bool UsageStats::GetTimingForTest(const string &name,
-                                  uint64 *total_time,
-                                  uint32 *num_timings,
-                                  uint32 *avg_time,
-                                  uint32 *min_time,
-                                  uint32 *max_time) {
+bool UsageStats::GetTimingForTest(const std::string &name, uint64 *total_time,
+                                  uint32 *num_timings, uint32 *avg_time,
+                                  uint32 *min_time, uint32 *max_time) {
   Stats stats;
   if (!GetterInternal(name, Stats::TIMING, &stats)) {
     return false;
@@ -301,7 +213,8 @@ bool UsageStats::GetTimingForTest(const string &name,
   return true;
 }
 
-bool UsageStats::GetVirtualKeyboardForTest(const string &name, Stats *stats) {
+bool UsageStats::GetVirtualKeyboardForTest(const std::string &name,
+                                           Stats *stats) {
   if (!GetterInternal(name, Stats::VIRTUAL_KEYBOARD, stats)) {
     return false;
   }
@@ -315,59 +228,20 @@ bool UsageStats::GetVirtualKeyboardForTest(const string &name, Stats *stats) {
   return true;
 }
 
-bool UsageStats::GetStatsForTest(const string &name, Stats *stats) {
+bool UsageStats::GetStatsForTest(const std::string &name, Stats *stats) {
   return LoadStats(name, stats);
 }
 
 void UsageStats::StoreTouchEventStats(
-    const string &name,
-    const std::map<string, TouchEventStatsMap> &touch_stats) {
+    const std::string &name,
+    const std::map<std::string, TouchEventStatsMap> &touch_stats) {
   DCHECK(IsListed(name)) << name << " is not in the list";
-  if (touch_stats.empty()) {
-    return;
-  }
-
-  Stats stats;
-  std::map<string, TouchEventStatsMap> tmp_stats(touch_stats);
-  if (GetterInternal(name, Stats::VIRTUAL_KEYBOARD, &stats)) {
-    for (size_t i = 0; i < stats.virtual_keyboard_stats_size(); ++i) {
-      const Stats::VirtualKeyboardStats &virtual_keyboard_stats =
-          stats.virtual_keyboard_stats(i);
-      const string &keyboard_name = virtual_keyboard_stats.keyboard_name();
-      TouchEventStatsMap &stats_map = tmp_stats[keyboard_name];
-
-      for (size_t j = 0; j < virtual_keyboard_stats.touch_event_stats_size();
-          ++j) {
-        const Stats::TouchEventStats &src_stats =
-            virtual_keyboard_stats.touch_event_stats(j);
-        Stats::TouchEventStats &dest_stats = stats_map[src_stats.source_id()];
-        AddTouchEventStats(src_stats, &dest_stats);
-      }
-    }
-  } else {
-    stats.set_name(name);
-    stats.set_type(Stats::VIRTUAL_KEYBOARD);
-  }
-
-  stats.clear_virtual_keyboard_stats();
-  for (std::map<string, TouchEventStatsMap>::const_iterator iter =
-           tmp_stats.begin();
-       iter != tmp_stats.end(); ++iter) {
-    Stats::VirtualKeyboardStats *virtual_keyboard_stats =
-        stats.add_virtual_keyboard_stats();
-    virtual_keyboard_stats->set_keyboard_name(iter->first);
-    for (TouchEventStatsMap::const_iterator it = iter->second.begin();
-        it != iter->second.end(); ++it) {
-      Stats::TouchEventStats *touch_event_stats =
-          virtual_keyboard_stats->add_touch_event_stats();
-      touch_event_stats->CopyFrom(it->second);
-    }
-  }
-
-  SetterInternal(name, stats);
+  // Does nothing
 }
 
 bool UsageStats::Sync() {
+  ClearAllStats();                      // Clears accumulated data.
+  UsageStatsUploader::ClearMetaData();  // Clears meta data to send usage stats.
   if (!storage::Registry::Sync()) {
     LOG(ERROR) << "sync failed";
     return false;
